from rfc3339 import convert_datetime  # noqa
from tasks import set_task_percentage  # noqa
from metadata import Metadata  # noqa
from connections import Connections  # noqa
from image_detail import ImageDetail, ImageDetailMap  # noqa
from ip_address import IpAddress  # noqa
from locations import Region, Locations  # noqa
from resource import Resource  # noqa
from appliance import Appliance  # noqa
from network import Network  # noqa
from server import Server  # noqa
from service_offering import ServiceOffering  # noqa
from compute_pool import ComputePool  # noqa
from volume import Volume  # noqa
from account import Account  # noqa
from saas_user import SaasUser  # noqa
from tools import serialize_list, vcr_cassette_context  # noqa
from colo_space import ColoSpace  # noqa

from ._version import get_versions
__version__ = get_versions()['version']
del get_versions
